@@ -1,10 +1,14 @@
-//   cstypes.h   part of cim-sity
-//   This contains the types of map points and their graphic files.
-// Copyright (c) I J Peters 1995,1996.  Please read the file 'COPYRIGHT'.
+/* ---------------------------------------------------------------------- *
+ * lctypes.h
+ * This file is part of lincity.
+ * Lincity is copyright (c) I J Peters 1995-1997, (c) Greg Sharp 1997-2001.
+ * ---------------------------------------------------------------------- */
+#ifndef __lctypes_h__
+#define __lctypes_h__
 
 #define CST_GREEN	0
 #define CST_GREEN_G		"green.csi"
-// H=horiz V=vertical LD=left down etc.   L= Live D=dead
+/* H=horiz V=vertical LD=left down etc.   L= Live D=dead */
 #define CST_POWERL_H_L		1
 #define CST_POWERL_H_L_G	"powerlhl.csi"
 #define CST_POWERL_V_L  	2
@@ -54,7 +58,7 @@
 #define CST_SHANTY              23
 #define CST_SHANTY_G            "shanty.csi"
 
-// move this to number 1 or 255 or something. OK here for now.
+/* move this to number 1 or 255 or something. OK here for now. */
 #define CST_USED		39
 
 #define CST_POWERS_SOLAR	40
@@ -603,8 +607,10 @@
 #define CST_FARM_O16             348
 #define CST_FARM_O16_G           "farm16.csi"
 
+/*
+  //    *********************************
+  //    400 is the maximum at the moment.
+  //    *********************************
+*/
 
-//    *********************************
-//    400 is the maximum at the moment.
-//    *********************************
-
+#endif /* __lctypes_h__ */
